carp_context_package library
A library for collecting context information on:
- location (both as one-time and continuous location data)
- geofence
- activity
- weather
- air quality
- mobility features
Classes
- Activity
- Holds an activity event as recognized by the phone Activity Recognition (AR) API.
- ActivityProbe
- Collects activity information from the underlying OS's activity recognition API. It generates an Activity every time an activity is detected.
- AirQuality
-
A
Datathat holds air quality information collected via the World's Air Quality Index (WAQI) API. - AirQualityProbe
- Collects local air quality information using the AirQuality plugin.
- AirQualitySamplingPackage
- The air quality sampling package.
- AirQualityService
- A service configuration for the air quality service.
- AirQualityServiceManager
-
A
DeviceManagerfor the AirQualityService. - CircularGeofence
- A class representing a circular geofence with a center, a radius (in meters) and a name.
- ConfigurableLocationProbe
- A probe that collects location data from the underlying OS's location API.
- ContextSamplingPackage
- This is the base class for this context sampling package.
-
ContextServiceManager<
TDeviceConfiguration extends ServiceConfiguration< ServiceRegistration> > - Geofence
- Holds information about a geofence event of entering, exiting, or dwelling.
- GeofenceProbe
-
Listen on location movements and reports a Geofence to the stream
when a geofence event happens. This probe can handle only one measure.
If you need multiple geofences, add a
GeofenceMeasurefor each to yourStudyfor example using theTriggermodel. - GeofenceSamplingConfiguration
- Specify the configuration of a circular geofence measure, specifying the:
- GeoPosition
- Position coordinated in Degrees (i.e. GPS-style).
- Location
- Holds location information using the GPS format from the phone.
- LocationManager
- A manger that knows how to get location information. Provide access to location data while the app is in the background.
- LocationProbe
-
Collects streaming location information from the underlying OS's location API.
Is a
StreamProbethat generates a Location data point every time location is changed. - LocationSamplingConfiguration
- A sampling configuration for location sampling. This configuration allows for specifying if the location should be sampled only once.
- LocationSamplingPackage
- The location sampling package.
- LocationService
-
An
OnlineServicefor the location manager. - LocationServiceManager
-
A
DeviceManagerfor the location service. - Mobility
- Holds mobility features information.
- MobilityProbe
-
Collects mobility features using the
MobilityFeaturesAPI. - MobilitySamplingConfiguration
- Specify the configuration on how to measure mobility features.
- OMHContextDataPoint
-
A
Datawhich can hold an OMH DataPoint and provide its correct OMHformatand provenance. - OMHGeopositionDataPoint
- Holds an OMH Geoposition data point.
- OMHPhysicalActivityDataPoint
- Holds an OMH PhysicalActivity data point.
- Weather
- Holds weather information collected through OpenWeather API.
- WeatherProbe
- Collects local weather information using the WeatherServiceManager.
- WeatherSamplingPackage
- The weather sampling package.
- WeatherService
-
An
OnlineServicefor the Open Weather service. - WeatherServiceManager
-
A
DeviceManagerfor the WeatherService.
Enums
- ActivityType
- Defines the type of activity.
- AirQualityLevel
- Level of air quality.
- GeofenceState
- The possible states of a geofence.
- GeofenceType
- GeolocationAccuracy
- The precision of the Location. A lower precision will provide a greater battery life.