Activity class

Holds an activity event as recognized by the phone Activity Recognition (AR) API.

Inheritance
  • Object
  • Serializable
  • Data
  • Activity
Annotations
  • @JsonSerializable.new(includeIfNull: false, explicitToJson: true)

Constructors

Activity({required ActivityType type, required int confidence})
Activity.fromActivity(Activity activity)
factory
Activity.fromJson(Map<String, dynamic> json)
factory

Properties

$type String?
The runtime class name (type) of this object. Used for deserialization from JSON objects.
getter/setter pairinherited
confidence int
Confidence in activity recognition.
getter/setter pair
dataType → DataType
The type of this data as a DataType.
no setterinherited
fromJsonFunction Function
The function which can convert a JSON string to an object of this type.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
jsonType String
Return the __type to be used for JSON serialization of this class. Default is runtimeType. Only specify this if you need another type.
no setterinherited
recordId String?
Stable identifier of the source record, if available.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type ActivityType
Type of activity recognized.
getter/setter pair
typeString String
Activity type as a string.
no setter

Methods

equivalentTo(Data other) bool
Is this data equivalent to other?
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Return a JSON encoding of this object.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited