AirQuality class
A Data that holds air quality information collected via the
World's Air Quality Index (WAQI) API.
- Inheritance
-
- Object
- Serializable
- Data
- AirQuality
- Annotations
-
- @JsonSerializable.new(includeIfNull: false, explicitToJson: true)
Constructors
- AirQuality({required int airQualityIndex, String? source, String? place, required double latitude, required double longitude, AirQualityLevel? airQualityLevel})
- AirQuality.fromAirQualityData(AirQualityData airQualityData)
-
AirQuality.fromJson(Map<
String, dynamic> json) -
factory
Properties
- $type ↔ String?
-
The runtime class name (type) of this object.
Used for deserialization from JSON objects.
getter/setter pairinherited
- airQualityIndex ↔ int
-
getter/setter pair
- airQualityLevel ↔ AirQualityLevel?
-
getter/setter pair
- dataType → DataType
-
The type of this data as a
DataType.no setterinherited - fromJsonFunction → Function
-
The function which can convert a JSON string to an object of this type.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- jsonType → String
-
Return the
__typeto be used for JSON serialization of this class. Default is runtimeType. Only specify this if you need another type.no setteroverride - latitude ↔ double
-
getter/setter pair
- longitude ↔ double
-
getter/setter pair
- place ↔ String?
-
getter/setter pair
- recordId → String?
-
Stable identifier of the source record, if available.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source ↔ String?
-
getter/setter pair
Methods
-
equivalentTo(
Data other) → bool -
Is this data equivalent to
other?inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Return a JSON encoding of this object.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited