LocationSamplingConfiguration class

A sampling configuration for location sampling. This configuration allows for specifying if the location should be sampled only once.

Usage:

Measure(type: ContextSamplingPackage.LOCATION)
  ..overrideSamplingConfiguration = LocationSamplingConfiguration(once: true),
Inheritance
  • Object
  • Serializable
  • SamplingConfiguration
  • LocationSamplingConfiguration
Annotations
  • @JsonSerializable.new(includeIfNull: false, explicitToJson: true)

Constructors

LocationSamplingConfiguration({bool once = false})
LocationSamplingConfiguration.fromJson(Map<String, dynamic> json)
factory

Properties

$type String?
The runtime class name (type) of this object. Used for deserialization from JSON objects.
getter/setter pairinherited
fromJsonFunction Function
The function which can convert a JSON string to an object of this type.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
jsonType String
Return the __type to be used for JSON serialization of this class. Default is runtimeType. Only specify this if you need another type.
no setterinherited
once bool
Should the location be sampled only once?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Return a JSON encoding of this object.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited