LocationService class

An OnlineService for the location manager.

Inheritance
  • Object
  • Serializable
  • DeviceConfiguration<ServiceRegistration>
  • CamsDevice<ServiceRegistration>
  • ServiceConfiguration<ServiceRegistration>
  • LocationService
Annotations
  • @JsonSerializable.new(includeIfNull: false, explicitToJson: true)

Constructors

LocationService({String? roleName, GeolocationAccuracy accuracy = GeolocationAccuracy.balanced, double distance = 10, Duration interval = const Duration(minutes: 1), String? notificationTitle, String? notificationMessage, String? notificationDescription, String? notificationIconName, bool notificationOnTapBringToFront = false})
Create and configure a LocationService.
LocationService.fromJson(Map<String, dynamic> json)
factory

Properties

$type String?
The runtime class name (type) of this object. Used for deserialization from JSON objects.
getter/setter pairinherited
accuracy GeolocationAccuracy
Defines the desired accuracy that should be used to determine the location data. Default value is GeolocationAccuracy.balanced.
getter/setter pair
dataTypeSamplingSchemes → DataTypeSamplingSchemeMap?
Sampling schemes for all the sensors available on this device.
no setterinherited
defaultSamplingConfiguration Map<String, SamplingConfiguration>?
Sampling configurations which override the default configurations for data types available on this device.
getter/setter pairinherited
distance double
The minimum distance in meters a device must move horizontally before an update event is generated. Specify 0 when you want to be notified of all movements.
getter/setter pair
fromJsonFunction Function
The function which can convert a JSON string to an object of this type.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
interval Duration
The time interval between location updates.
getter/setter pair
isOptional bool?
Determines whether device registration for this device is optional prior to starting a study, i.e., whether the study can run without this device or not.
getter/setter pairinherited
jsonType String
Return the __type to be used for JSON serialization of this class. Default is runtimeType. Only specify this if you need another type.
no setterinherited
notificationDescription String?
The longer description in the notification to be shown to the user when location tracking takes place in the background. Only used on Android.
getter/setter pair
notificationIconName String?
The icon in Android/app/main/res/drawable folder. Only used on Android.
getter/setter pair
notificationMessage String?
The message in the notification to be shown to the user when location tracking takes place in the background. Only used on Android.
getter/setter pair
notificationOnTapBringToFront bool
Should the app be brought to the front on tap? Default is false.
getter/setter pair
notificationTitle String?
The title of the notification to be shown to the user when location tracking takes place in the background. Only used on Android.
getter/setter pair
roleName String
A name which describes how the device participates within the study protocol; it's 'role'. For example, 'Parent's phone' or 'Child phone'.
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
supportedDataTypes Set<String>?
The set of data types which can be collected on this device.
no setterinherited
type String
The device type identifier
no setterinherited

Methods

createRegistration({String? deviceId, String? deviceDisplayName}) → ServiceRegistration
Create a DeviceRegistration which can be used to configure this device for deployment.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Return a JSON encoding of this object.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

DEFAULT_ROLE_NAME → const String
The default role name for a location service.
DEVICE_TYPE → const String
The type of a location service.