ContextServiceManager<TDeviceConfiguration extends ServiceConfiguration<ServiceRegistration > > class
abstract
Inheritance
Object
DeviceManager<TDeviceConfiguration , ServiceRegistration >
ServiceManager<TDeviceConfiguration , ServiceRegistration >
ContextServiceManager
Implemented types
Implementers
Properties
canConnect
→ bool
Determines whether a connection can be made at this point in time to the device.
no setter override
configuration
→ TDeviceConfiguration?
The configuration for this device.
no setter inherited
deviceType
→ String
The type of the device managed by this device manager
no setter inherited
displayName
→ String ?
no setter inherited
executors
→ Set <TaskControlExecutor >
The set of task control executors that use this device manager.
final inherited
hashCode
→ int
The hash code for this object.
no setter inherited
isConfigured
→ bool
Has this device manager been configured?
no setter inherited
isConnected
→ bool
Is this device manager connected to the real device?
no setter inherited
isConnecting
→ bool
Is this device manager connecting or already connected to a device?
no setter inherited
registration
→ ServiceRegistration?
The latest registration for this device.
no setter inherited
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
shouldConnect
→ bool
Indicates whether this device manager should connect to the real device
based on the last known registration information.
Returns true (default) if no prior registration information is available,
no setter override
status
↔ DeviceStatus
The runtime status of this device.
getter/setter pair inherited
statusEvents
→ Stream <DeviceStatus >
The stream of status events for this device.
no setter inherited
supportedDataTypes
→ Set <DataType >
The set of data types defining which data can be collected on this device.
no setter inherited
typeName
→ String
The name of the deviceType without the namespace.
no setter inherited
Methods
configure (TDeviceConfiguration configuration , [ServiceRegistration? registration ])
→ void
Configure this device manager by specifying its configuration.
Optionally, a registration can be specified to provide runtime information
about the real device, e.g., the BLE address of a Bluetooth device.
inherited
connect ()
→ Future <DeviceStatus >
Ask this DeviceManager to start connecting to the device.
Returns the DeviceStatus of the device.
inherited
createRegistration ()
→ ServiceRegistration
Create a device registration which can be used to configure this device
for deployment.
override
disconnect ()
→ Future <bool >
Ask this DeviceManager to disconnect from the device.
inherited
hasPermissions ()
→ Future <bool >
Does this device manager have the permissions to run?
inherited
isDisconnecting ()
→ Future <void >
Callback when the physical device is disconnected due to e.g., a temporary
loss of Bluetooth connection.
inherited
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onConfigure ()
→ void
Callback on configure .
override
onConnect ()
→ Future <DeviceStatus >
Callback on connect. Returns the DeviceStatus of the device.
inherited
onDisconnect ()
→ Future <bool >
Callback on disconnect .
override
onHasPermissions ()
→ Future <bool >
Callback on hasPermissions .
override
onRequestPermissions ()
→ Future <void >
Callback on requestPermissions .
override
requestPermissions ()
→ Future <void >
Request all permissions for this device manager.
inherited
restart ()
→ void
Restart sampling of the measures using this device.
inherited
start ()
→ void
Start sampling of all measures using this device.
inherited
stop ({bool shouldBeResumed = false })
→ void
Stop sampling the measures using this device.
inherited
toString ()
→ String
A string representation of this object.
inherited
carp_context_package 2.1.0